@@ -1,5 +1,15 @@
 .onLoad = function(libname, pkgname) {
   .jpackage(pkgname, lib.loc = libname)
+  
+  #need to check if proper Java is installed by special request of Prof Brian Ripley
+  jv = .jcall("java/lang/System", "S", "getProperty", "java.runtime.version")
+  if (substr(jv, 1L, 1L) == "1") {
+	  jvn = as.numeric(paste0(strsplit(jv, "[.]")[[1L]][1:2], collapse = "."))
+	  if (jvn < 1.7){
+	  	stop("Java 7 (at minimum) is needed for this package but is not available.")
+	  }		
+  }
+  
   assign("bartMachine_globals", new.env(), envir = parent.env(environment()))
 }
 
